@@ -5,7 +5,7 @@ from trexlib.utils.google.cloud_tasks_util import create_task
 import logging
 from trexlib.utils.log_util import get_tracelog
 from trexlib.utils.string_util import random_string
-from trexlib import conf as lib_conf
+from trexconf import conf as lib_conf
 from datetime import datetime
 logger = logging.getLogger('task')
 
@@ -151,7 +151,10 @@ class InitTaskBaseResource(TriggerTaskBaseResource):
         pass
     
 
-class TaskBaseResource(InitTaskBaseResource):    
+class TaskBaseResource(InitTaskBaseResource): 
+    
+    def post(self):
+        return self.get()   
     
     def get(self):
         content         = request.args.to_dict() or request.json or {}
