@@ -4,14 +4,13 @@ Created on 13 Jan 2021
 @author: jacklok
 '''
 from google.cloud import tasks_v2
-from trexlib import conf as lib_conf
+from trexconf import conf as lib_conf 
 import logging, json
 from datetime import datetime, timedelta
 from google.oauth2 import service_account 
 from google.protobuf import timestamp_pb2
 from trexlib.utils.security_util import create_basic_authentication, verfiy_basic_authentication
 from trexlib.utils.string_util import random_string
-#from trexlib.conf import SYSTEM_TASK_SERVICE_ACCOUNT_KEY, SYSTEM_TASK_GCLOUD_PROJECT_ID, SYSTEM_TASK_GCLOUD_LOCATION, SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL
 
 logger = logging.getLogger('utils-debug')
 
@@ -54,7 +53,9 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
             payload = json.dumps(payload)
             # specify http content-type to application/json
             task["http_request"]["headers"] = {"Content-type": "application/json"}
-    
+        else:
+            task["http_request"]["headers"] = {"Content-type": "application/x-www-form-urlencoded"}
+            
         # The API expects a payload of type bytes.
         converted_payload = payload.encode()
         
@@ -62,7 +63,9 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
     
         # Add the payload to the request.
         task["http_request"]["body"] = converted_payload
-    
+    else:
+        task["http_request"]["headers"] = {"Content-type": "application/x-www-form-urlencoded"}
+        
     
     if headers is not None:
         for k,v in headers.items():
@@ -87,6 +90,8 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
     
     response = client.create_task(request={"parent": parent, "task": task})
     
+    logger.info('response=%s', response)
+    
     return response
 
 
