@@ -6,7 +6,7 @@ Created on 24 Dec 2020
 import logging, json
 from google.oauth2 import service_account
 from google.cloud import storage
-from trexlib import conf as lib_conf
+from trexconf import conf as lib_conf
 
 logger = logging.getLogger('debug')
 
