@@ -1,5 +1,5 @@
 import hashlib, hmac, time, uuid, json
-from trexlib import conf
+from trexconf import conf
 import logging
 from basicauth import encode as basic_encode, decode as basic_decode
 
